#The purpose of this script is to reproduce Touwsranten paper 1 analyses
#07 MARCH 2023

#One hash is used to comment {#}
#Double hashes are used to indicate where the user must insert of adjust code {##}
#Multiple consecutive hashes (>2) are used to separate sections of the script {###################################################################}

####################################################################################################################################################
#The major aim of this study is to assess community-wide stability in 
#(1) positive parenting (2) child internalising (3) externaling (4) parental stress and use of corporal punishment across 3 waves from 2012 to 2016, 
#a baseline period prior to the introduction of parenting interventions within the Touwsranten community, which were first rolled out in 2017.
####################################################################################################################################################

#Preamble settings
rm(list=ls())
library(pacman)
p_load(tidyverse, readxl, ggplot2, knitr, ggcorrplot, psych, markdown,prettydoc, nlme, Rmisc, gridExtra, lme4, kableExtra, 
       sjPlot, lmerTest,semTools, gtsummary, nonpar, rstatix)
#Set current directory
##setwd()

#Import Touwsranten dataset (waves 1-5)
Independentdyads_Waves1to3=read.csv("W1W2W3W4W5_Touwsranten.dataset.v1.csv")%>%
  filter(Wave == 1|Wave == 2 | Wave == 3)%>%
  #Remove dependent observations (Same child, different parents)
  filter(!ParentsID == 1.1) %>%
  #Filter to include only children aged 6-18 years (includes some children > 18 years)
  filter(ChildAge_cat == 1)

#######################################################################################################################################
#Reliability checks (cronbach's alpha)

#APQ total score
APQ.reliability <-
  '
APQ =~ FriendlyTalk.APQ+SpecialActivities.APQ+ PlayGames.APQ+ AskAboutSchool.APQ+ HomeworkHelp.APQ+
AskAboutPlans.APQ+TakesToActivity.APQ+TalkAboutFriends.APQ+PlanningFamilyActivities.APQ+AttendsMeetings.APQ+ 
GoodJob.APQ+RewardBehaviour.APQ+Compliments.APQ+PraiseBehaviour.APQ+HugsKisses.APQ+ LikesHelp.APQ+ 
LeavesNote.APQ+StaysOutTooLate.APQ+DoNotKnowFriends.APQ+NoCurfew.APQ+OutLateWithoutAdult.APQ+ForgetChild.APQ+
CheckHomeTime.APQ+TellChildYourWhereabouts.APQ+LateFromSchool.APQ+HomeSupervision.APQ+ThreatenPunishment.APQ+
NegotiatePunishment.APQ+Obedience.APQ+LetOutPunishment.APQ+PunishesBehaviour.APQ+PunishmentMood.APQ
'
APQ.fit = cfa(APQ.reliability, data = Independentdyads_Waves1to3)
APQ_parenting=reliability(APQ.fit)[1,1]

#APQ involvement subscale
APQ.Involvement_reliability <-
  '
APQ_Involvement =~ FriendlyTalk.APQ+SpecialActivities.APQ+ PlayGames.APQ+ AskAboutSchool.APQ+ HomeworkHelp.APQ+
AskAboutPlans.APQ+TakesToActivity.APQ+TalkAboutFriends.APQ+PlanningFamilyActivities.APQ+AttendsMeetings.APQ
'
APQ.Involvement_fit = cfa(APQ.Involvement_reliability, data = Independentdyads_Waves1to3)
APQ.Involvement_parenting=reliability(APQ.Involvement_fit)[1,1]

#APQ positive parenting subscale
APQ.PosPar_reliability <-
  '
APQ_PosPar =~ GoodJob.APQ+RewardBehaviour.APQ+Compliments.APQ+PraiseBehaviour.APQ+HugsKisses.APQ+ LikesHelp.APQ
'
APQ.PosPar_fit = cfa(APQ.PosPar_reliability, data = Independentdyads_Waves1to3)
APQ.PosPar_parenting=reliability(APQ.PosPar_fit)[1,1]

#APQ poor monitoring subscale
APQ.PoorMon_reliability <-
  '
APQ_PoorMon =~ LeavesNote.APQ+StaysOutTooLate.APQ+DoNotKnowFriends.APQ+NoCurfew.APQ+OutLateWithoutAdult.APQ+ForgetChild.APQ+CheckHomeTime.APQ+TellChildYourWhereabouts.APQ+LateFromSchool.APQ+HomeSupervision.APQ
'
APQ.PoorMon_fit = cfa(APQ.PoorMon_reliability, data = Independentdyads_Waves1to3)
APQ.PoorMon_parenting=reliability(APQ.PoorMon_fit)[1,1]

#APQ inconsistent discipline subscale
APQ.InconDiscipline_reliability <-
  '
APQ_InconDiscipline =~ ThreatenPunishment.APQ+NegotiatePunishment.APQ+Obedience.APQ+LetOutPunishment.APQ+PunishesBehaviour.APQ+PunishmentMood.APQ
'
APQ.InconDiscipline_fit = cfa(APQ.InconDiscipline_reliability, data = Independentdyads_Waves1to3)
APQ.InconDiscipline_parenting=reliability(APQ.InconDiscipline_fit)[1,1]

#APQ corporal punishment subscale
APQ.corp.reliability <-
  '
APQ_CorpPun =~ SpankHand.APQ+SlapChild.APQ+HitsWithBelt.APQ
'
APQ.corp.fit = cfa(APQ.corp.reliability, data = Independentdyads_Waves1to3)
APQ_corporal_punishment=reliability(APQ.corp.fit)[1,1]

#Parent stress total
PSISF.reliability <-
  '
PSISF_Total_ParentStress =~ NotHandle.PSISF+GivingMore.PSISF+Trapped.PSISF+
    UnableNewThings.PSISF+UnableTodoThingsILike.PSISF+ClothingPurchaseUnhappy.PSISF+
    ThingsBother.PSISF+RelationshipProblem.PSISF+Lonely.PSISF+PartyNotEnjoy.PSISF+
    NoInterestPeople.PSISF+NoEnjoyment.PSISF+ChildNotMakeFeelGood.PSISF+
    ChildDislikesMe.PSISF+ChildSmilesLess.PSISF+ChildUnappreciative.PSISF+
    ChildNotLaugh.PSISF+ChildSlowLearnOthers.PSISF+ChildSmileLessOthers.PSISF+
    ChildDoLess.PSISF+ChildSlowAdapt.PSISF+Parent.PSISF+WarmerFeelingsToChild.PSISF+
    ChildDoesThings.PSISF+ChildCryFuss.PSISF+ChildWakesBadMood.PSISF+ChildVeryMoody.PSISF+
    ChildThingsBotherMe.PSISF+ChildReactsStrongly.PSISF+ChildUpsetEasily.PSISF+
    ChildSleepingEating.PSISF+GettingChildToDoSomething.PSISF+CountThingsThatBother.PSISF+
    ChildDoesBotherALot.PSISF+ChildMoreProblem.PSISF+ChildDemands.PSISF
'
PSISF.fit = cfa(PSISF.reliability, data = Independentdyads_Waves1to3)
PSISF_parental_stress=reliability(PSISF.fit)[1,1]

#Conflict tactics scale
CTS.reliability <-
  '
CTS_IPV =~ PartnerInsultedSwore.CTS+IInsultedSwore.CTS+PartnerThrew.CTS+IThrew.CTS+
    PartnerTwisted.CTS+ITwisted.CTS+PartnerPushed.CTS+IPushed.CTS+PartnerKnifeGun.CTS+
    IKnifeGun.CTS+PartnerPunchedHit.CTS+IPunchedHit.CTS+PartnerChoked.CTS+IChoked.CTS+
    PartnerShoutedYelled.CTS+IShoutedYelled.CTS+PartnerSlammed.CTS+ISlammed.CTS+
    PartnerBeat.CTS+IBeat.CTS+PartnerGrabbed.CTS+IGrabbed.CTS+PartnerStomped.CTS+
    IStomped.CTS+PartnerSlapped.CTS+ISlapped.CTS+PartnerBurnedScalded.CTS+
    IBurnedScalded.CTS+PartnerSpite.CTS+ISpite.CTS+PartnerKickedBitPunched.CTS+
    IKickedBitPunched.CTS
'
CTS.fit = cfa(CTS.reliability, data = Independentdyads_Waves1to3)
CTS_Intimate_partner_violence=reliability(CTS.fit)[1,1]

#CBCL Internalising subscale (6-18 year)
CBCL.Older.Internal.reliability <-
  '
CBCL_Older_Internalising =~ CriesALot6to18.CBC+FearsOtherThanSchool6to18.CBC+
    FearsSchool6to18.CBC+FearsDoingBad6to18.CBC+NeedForPerfection6to18.CBC+ComplainNoLove6to18.CBC+
    FeelsInferior6to18.CBC+NervousTense6to18.CBC+ FearfulAnxious6to18.CBC+ TooGuilty6to18.CBC+
    SelfconciousEasilyEmbarrassed6to18.CBC+ SuicideTalk6to18.CBC+Worries6to18.CBC+ Nightmares6to18.CBC+Constipated6to18.CBC+
    DizzyLightheaded6to18.CBC+ Overtired6to18.CBC+ AchesPains6to18.CBC+ 
    Headaches6to18.CBC+Nausea6to18.CBC+EyeProblems6to18.CBC+SkinRashes6to18.CBC+StomachAches6to18.CBC+ Vomiting6to18.CBC+ VeryLittleEnjoyment6to18.CBC+PrefersBeingAlone6to18.CBC+
    RefuseToTalk6to18.CBC+Secretive6to18.CBC+ShyTimid6to18.CBC+UnderactiveLacksEnergy6to18.CBC+
    UnhappyDepressed6to18.CBC+ Withdrawn6to18.CBC
'
CBCL.Older.Internal.fit = cfa(CBCL.Older.Internal.reliability, data = Independentdyads_Waves1to3)
CBCL_Internalising_older=reliability(CBCL.Older.Internal.fit)[1,1]

#CBCL Externalising subscale (6-18 year)
CBCL.Older.External.reliability <-
  '
CBCL_Older_Externalising =~ ArguesALot6to18.CBC+CrueltyToOthers6to18.CBC+ 
    DemandsAttention6to18.CBC+ DestroysOwnThings6to18.CBC+ DestroysOthersThings6to18.CBC+ 
    DisobedientAtHome6to18.CBC+ DisobedientAtSchool6to18.CBC+ InManyFights6to18.CBC+ 
    PhysicallyAttacks6to18.CBC+ ScreamsFrequently6to18.CBC+ StubbornSullenIrritable6to18.CBC+
    ChangedMoods6to18.CBC+ Sulks6to18.CBC+ Suspicious6to18.CBC+ TeasesALot6to18.CBC+ 
    TemperTantrums6to18.CBC+ ThreatensPeople6to18.CBC+ UnusuallyLoud6to18.CBC+ AlcoholWithoutApproval6to18.CBC+ 
    GuiltAfterMisbehaving6to18.CBC+BreaksRules6to18.CBC+TroubleMakerFriends6to18.CBC+
    LyingCheating6to18.CBC+PrefersOlderKids6to18.CBC+RunsAway6to18.CBC+ SetsFires6to18.CBC+ 
    SexualProblems6to18.CBC+ StealsAtHome6to18.CBC+StealsOutsideHome6to18.CBC+Swearing6to18.CBC+
    ObsessedWithSex6to18.CBC+ SmokesTobacco6to18.CBC+ Truancy6to18.CBC+UsesDrugs6to18.CBC+Vandalism6to18.CBC
'
CBCL.Older.External.fit = cfa(CBCL.Older.External.reliability, data = Independentdyads_Waves1to3)
CBCL_Externalising_older=reliability(CBCL.Older.External.fit)[1,1]

#General health questionnaire total
GHQ.reliability <-
  '
GHQ_GeneralHealth =~ WellGoodHealth.GHQ+NeedGoodTonic.GHQ+RunDown.GHQ+FeltIll.GHQ+
    PainsInHead.GHQ+TightnessInHead.GHQ+HotColdSpells.GHQ+LostSleepWorry.GHQ+
    CantStayAsleep.GHQ+UnderStrain.GHQ+BadTempered.GHQ+ScaredPanicky.GHQ+GettingOnTop.GHQ+
    NervousStrungUp.GHQ+StayBusy.GHQ+TakingLonger.GHQ+DoingThingsWell.GHQ+
    SatisfiedTasks.GHQ+UsefulPart.GHQ+MakingDecisions.GHQ+EnjoyDailyActivities.GHQ+
    Worthless.GHQ+Hopeless.GHQ+LifeNotWorthLiving.GHQ+Suicide.GHQ+
    CantDoAnythingNerves.GHQ+WishingDead.GHQ+TakingOwnLife.GHQ
'
GHQ.fit = cfa(GHQ.reliability, data = Independentdyads_Waves1to3)
GHQ_General_health=reliability(GHQ.fit)[1,1]

#ASSIST alcohol subscale
ASSIST.reliability <-
  '
ASSIST_AlcoholSeverity =~ UsedAlcoholThreeMonths.ASSIST+UrgeAlcoholThreeMonths.ASSIST+
    AlcoholProblemsThreeMonths.ASSIST+AlcoholFailedToDoThreeMonths.ASSIST+FriendRelativeConcerned.ASSIST+
    ControlStopAlcoholUse.ASSIST
'
ASSIST.fit = cfa(ASSIST.reliability, data = Independentdyads_Waves1to3)
ASSIST_Alcohol_use=reliability(ASSIST.fit)[1,1]

#Collate and print reliability estimates
reliable=rbind(APQ_parenting,APQ.Involvement_parenting,APQ.PosPar_parenting, APQ.PoorMon_parenting, APQ.InconDiscipline_parenting, 
               APQ_corporal_punishment, PSISF_parental_stress, CTS_Intimate_partner_violence,  CBCL_Internalising_older, 
               CBCL_Externalising_older, GHQ_General_health, ASSIST_Alcohol_use)
reliable
#Note: Reliability of APQ poor monitoring subscale is < .70 in waves 1-3, but was kept in the APQ total to maintain consistency with APQ total reported in paper 2 (Waves 3-5)
#APQ total in paper 2 includes all subscales except inconsistent discipline (mirroring paper 1)

####################################################################################################################################################
#Descriptives (for waves 1-3)
#Children aged 6-18 years

All.descriptives = Independentdyads_Waves1to3%>%
  dplyr::select(Wave, ChildGender, ChildAge,ParentGender, ParentAge, Relation,APQ_total.wAverage.FINAL,
                APQ_PosPar.subsc, APQ_PoorMon.subsc,APQ_Involvement.subsc, APQ_InconDiscipline.subsc,
                SpankHand.APQ, SlapChild.APQ,HitsWithBelt.APQ,CBCL_Older_Internalising.tscore,CBCL_Older_Externalising.tscore,
                CBCL_Older_Externalising.Dichotomous, CBCL_Older_Internalising.Threshold, CBCL_Older_Externalising.Threshold,
                GHQ_GeneralHealth.subsc, GHQ_GeneralHealth.Threshold, ASSIST_AlcoholSeverity.subsc,
                ASSIST_AlcoholSeverity.Threshold, PSISF_Total_ParentStress.subsc, PSISF_Total_ParentStress.percentile,
                CTS_IPV.subsc, CTS_IPV_categorical)

gtsummary::tbl_summary(All.descriptives, by = Wave,
                       type =  list(SpankHand.APQ ~ "continuous", 
                                    SlapChild.APQ ~ "continuous", 
                                    HitsWithBelt.APQ ~ "continuous", 
                                    CTS_IPV_categorical ~ "categorical"))%>%
                       bold_labels() %>% modify_header(label = "**Variable**")

##################################################################################################################
#Descriptives (for waves 1-3) of standardised variables
#Children aged 6-18 years

#Display mean and sd at Wave 3
All.descriptives%>%
  dplyr::select(-ChildGender, -contains("Threshold"), -contains("percentile"), -contains("categorical"), 
                -contains("Gender"), -ChildAge, -ParentAge,-Relation, -contains("Dichotomous"))%>%
  group_by(Wave)%>%
  summarise_all(funs(mean,sd), na.rm=TRUE)%>%
  mutate_all(funs(round(.,2)))%>%
  filter(Wave == 3)

#Standardise variables using mean and sd at wave 3 (mirroring paper 2) - chosen reference level

All.descriptives_std = All.descriptives%>%
  mutate(APQ_total_std = (APQ_total.wAverage.FINAL-4.07)/0.63)%>%
  mutate(APQ_PosPar_std = (APQ_PosPar.subsc-4.39)/0.73)%>%
  mutate(APQ_PoorMon_std = (APQ_PoorMon.subsc-1.95)/0.74)%>%
  mutate(APQ_Involvement_std = (APQ_Involvement.subsc-3.89)/0.83)%>%
  mutate(APQ_InconDiscipline_std = (APQ_InconDiscipline.subsc-2.83)/0.77)%>%
  mutate(SpankHand_std = (SpankHand.APQ-2.78)/1.61)%>%
  mutate(SlapChild_std = (SlapChild.APQ-1.32)/0.84)%>%
  mutate(HitsWithBelt_std = (HitsWithBelt.APQ-1.71)/1.31)%>%
  mutate(CBCL_Older_Internalising.tscore_std = (CBCL_Older_Internalising.tscore-49.37)/10.66)%>%
  mutate(CBCL_Older_Externalising.tscore_std = (CBCL_Older_Externalising.tscore-49.53)/11.14)%>%
  mutate(GHQ_GeneralHealth.subsc_std = (GHQ_GeneralHealth.subsc-2.01)/4.17)%>%
  mutate(ASSIST_AlcoholSeverity.subsc_std = (ASSIST_AlcoholSeverity.subsc-5.06)/7.92)%>%
  mutate(PSISF_Total_ParentStress.subsc_std = (PSISF_Total_ParentStress.subsc-85.52)/22)%>%
  mutate(CTS_IPV.subsc_std = (CTS_IPV.subsc-4.41)/9.54)%>%
  dplyr::select(Wave, contains("_std"))

gtsummary::tbl_summary(All.descriptives_std, missing = "no", by = Wave,
                       type =  list(SpankHand_std ~ "continuous", SlapChild_std ~ "continuous", 
                                    HitsWithBelt_std ~ "continuous"))%>%
                       bold_labels() %>% modify_header(label = "**Variable**")

#####################################################################################################################################################
#####################################################################################################################################################
#PARYC descriptives (at wave 3) for children aged 1.5-5 years
#Note that children aged 1.5-5 years were included from wave 3 onwards

PARYC.descriptives = read.csv("W1W2W3W4W5_Touwsranten.dataset.v1.csv")%>%
  filter(Wave == 3)%>%
  #Filter to include only children aged 1.5-5 years
  filter(ChildAge_cat == 0)%>%
  dplyr::select(Wave,contains("PARYC_"))

gtsummary::tbl_summary(PARYC.descriptives, missing = "no", by = Wave)%>%
                       bold_labels() %>% modify_header(label = "**Variable**")

##################################################################################################################
#PARYC descriptives (at wave 3) of standardised variables
#Children aged 1.5-5 years

#Display mean and sd at Wave 3
PARYC.descriptives %>%
  summarise_all(funs(mean,sd), na.rm=TRUE)%>%
  mutate_all(funs(round(.,2)))

#Standardise variables using mean and sd at baseline (Wave 1)
PARYC.descriptives_std = PARYC.descriptives%>%
  mutate(PARYC_total_std = (PARYC_SL.subsc-4.16)/1.43)%>%
  mutate(PARYC_SL_std = (PARYC_SL.subsc-3.99)/1.6)%>%
  mutate(PARYC_SPB_std = (PARYC_SPB.subsc-4.33)/1.58)%>%
  dplyr::select(contains("_std"))

gtsummary::tbl_summary(PARYC.descriptives_std, missing = "no")
