#The purpose of this script is to reproduce Touwsranten paper 1 analyses
#07 MARCH 2023
#Paper 1 inferential statistics

#One hash is used to comment {#}
#Double hashes are used to indicate where the user must insert of adjust code {##}
#Multiple consecutive hashes (>2) are used to separate sections of the script {###################################################################}

####################################################################################################################################################
#The major aim of this study is to assess community-wide stability in 
#(1) positive parenting (2) child internalising (3) externaling (4) parental stress and use of corporal punishment across 3 waves from 2012 to 2016, 
#a baseline period prior to the introduction of parenting interventions within the Touwsranten community, which were first rolled out in 2017.
####################################################################################################################################################

#Preamble settings
rm(list=ls())
library(pacman)
p_load(tidyverse, readxl, ggplot2, knitr, ggcorrplot, psych, markdown,prettydoc, nlme, Rmisc, gridExtra, lme4, kableExtra, 
       sjPlot, lmerTest,semTools, gtsummary, nonpar, rstatix)
#Set current directory
##setwd()

#Import Touwsranten dataset. Subset parent-child dyads with data at both wave 1 & 2 (N = 216) 
Consistentdyads_Waves1to2=read.csv("W1W2W3W4W5_Touwsranten.dataset.v1.csv")%>%
  filter(Wave == 1|Wave == 2)%>%
  group_by(UniqueDyadID)%>%
  filter(n()==2)%>%
  ungroup()

#Import Touwsranten dataset. Subset parent-child dyads with data at either wave 2 (N=166) or wave 3 (N = 204) but not both
Independentdyads_Waves2to3=read.csv("W1W2W3W4W5_Touwsranten.dataset.v1.csv")%>%
  filter(Wave == 2|Wave==3)%>%
  group_by(UniqueDyadID)%>%
  filter(!n()==2)%>%
  #Subset children > 6 years
  filter(ChildAge_cat == 1)

##################################################################################################################
#Inferential statistics of longitudinal subset (with data across waves 1-2) 

######################################################################################
#The purpose of these analyses is to test for stability/changes between waves 1 and 2
#Run wilcoxon signed ranked test for continuous variables
#Run McNemar chi-squared test for categorical variables
######################################################################################

Gender.long.mod = mcnemar.test(table(Consistentdyads_Waves1to2$ChildGender, Consistentdyads_Waves1to2$Wave))$p.value
ChildAge.long.mod = wilcox.test(Consistentdyads_Waves1to2$ChildAge, Consistentdyads_Waves1to2$Wave, paired = TRUE)$p.value
APQ_total.long.mod = wilcox.test(Consistentdyads_Waves1to2$APQ_total.wAverage.FINAL, Consistentdyads_Waves1to2$Wave, paired = TRUE)$p.value
APQ_posPar.long.mod = wilcox.test(Consistentdyads_Waves1to2$APQ_PosPar.subsc, Consistentdyads_Waves1to2$Wave, paired = TRUE)$p.value
APQ_poorMon.long.mod = wilcox.test(Consistentdyads_Waves1to2$APQ_PoorMon.subsc, Consistentdyads_Waves1to2$Wave, paired = TRUE)$p.value
APQ_Involve.long.mod = wilcox.test(Consistentdyads_Waves1to2$APQ_Involvement.subsc, Consistentdyads_Waves1to2$Wave, paired = TRUE)$p.value
APQ_spank.long.mod = wilcox.test(Consistentdyads_Waves1to2$SpankHand.APQ, Consistentdyads_Waves1to2$Wave, paired = TRUE)$p.value
APQ_slap.long.mod = wilcox.test(Consistentdyads_Waves1to2$SlapChild.APQ, Consistentdyads_Waves1to2$Wave, paired = TRUE)$p.value
APQ_Belt.long.mod = wilcox.test(Consistentdyads_Waves1to2$HitsWithBelt.APQ, Consistentdyads_Waves1to2$Wave, paired = TRUE)$p.value
CBCL_int.long.mod = wilcox.test(Consistentdyads_Waves1to2$CBCL_Internalising.tscore, Consistentdyads_Waves1to2$Wave, paired = TRUE)$p.value
CBCL_ext.long.mod = wilcox.test(Consistentdyads_Waves1to2$CBCL_Externalising.tscore, Consistentdyads_Waves1to2$Wave, paired = TRUE)$p.value
#Note that analyses cannot be run on GHQ total score as there is no variation in the variable (i.e., all score are 0)
#GHQ.health.long.mod = wilcox.test(Consistentdyads_Waves1to2$GHQ_GeneralHealth.subsc, Consistentdyads_Waves1to2$Wave, paired = TRUE)$p.value
ASSIST_alc.long.mod = wilcox.test(Consistentdyads_Waves1to2$ASSIST_AlcoholSeverity.subsc, Consistentdyads_Waves1to2$Wave, paired = TRUE)$p.value
PSISF_stress.long.mod = wilcox.test(Consistentdyads_Waves1to2$PSISF_Total_ParentStress.subsc, Consistentdyads_Waves1to2$Wave, paired = TRUE)$p.value
CTS_IPV.long.mod = wilcox.test(Consistentdyads_Waves1to2$CTS_IPV.subsc, Consistentdyads_Waves1to2$Wave, paired = TRUE)$p.value

pval = rbind(Gender.long.mod, ChildAge.long.mod, APQ_total.long.mod, APQ_posPar.long.mod,APQ_poorMon.long.mod, APQ_Involve.long.mod, APQ_spank.long.mod, APQ_slap.long.mod, APQ_Belt.long.mod,
             CBCL_int.long.mod, CBCL_ext.long.mod, ASSIST_alc.long.mod, PSISF_stress.long.mod, CTS_IPV.long.mod)
round(pval,3)

#####################################################################################################################################################
#####################################################################################################################################################
#Inferential statistics of independent subset (with data at waves 2 or 3 but not both) 

######################################################################################
#The purpose of these analyses is to test for differences between independent samples at 
#wave 2 vs wave 3
#Run wilcoxon ran sum test for continuous variables
#Run Pearson's chi-squared test for categorical variables
######################################################################################

Gender.ind.mod = chisq.test(table(Independentdyads_Waves2to3$ChildGender, Independentdyads_Waves2to3$Wave))$p.value
ChildAge.ind.mod = wilcox.test(ChildAge~ Wave, data = Independentdyads_Waves2to3)$p.value
APQ_total.ind.mod = wilcox.test(APQ_total.wAverage.FINAL~Wave)$p.value
APQ_posPar.ind.mod = wilcox.test(APQ_PosPar.subsc~Wave, Independentdyads_Waves2to3)$p.value
APQ_poorMon.ind.mod = wilcox.test(APQ_PoorMon.subsc~Wave, Independentdyads_Waves2to3)$p.value
APQ_Involve.ind.mod = wilcox.test(APQ_Involvement.subsc~Wave, Independentdyads_Waves2to3)$p.value
APQ_spank.ind.mod = wilcox.test(SpankHand.APQ~Wave, Independentdyads_Waves2to3)$p.value
APQ_slap.ind.mod = wilcox.test(SlapChild.APQ~Wave, Independentdyads_Waves2to3)$p.value
APQ_Belt.ind.mod = wilcox.test(HitsWithBelt.APQ~Wave, Independentdyads_Waves2to3)$p.value
CBCL_int.ind.mod = wilcox.test(CBCL_Internalising.tscore~Wave, Independentdyads_Waves2to3)$p.value
CBCL_ext.ind.mod = wilcox.test(CBCL_Externalising.tscore~Wave, Independentdyads_Waves2to3)$p.value
GHQ.health.ind.mod = wilcox.test(GHQ_GeneralHealth.subsc~Wave, Independentdyads_Waves2to3)$p.value
ASSIST_alc.ind.mod = wilcox.test(ASSIST_AlcoholSeverity.subsc~Wave, Independentdyads_Waves2to3)$p.value
PSISF_stress.ind.mod = wilcox.test(PSISF_Total_ParentStress.subsc~Wave, Independentdyads_Waves2to3)$p.value
CTS_IPV.ind.mod = wilcox.test(CTS_IPV.subsc~Wave, Independentdyads_Waves2to3)$p.value

pval = rbind(Gender.ind.mod, ChildAge.ind.mod, APQ_total.ind.mod, APQ_posPar.ind.mod,APQ_poorMon.ind.mod, APQ_Involve.ind.mod, APQ_spank.ind.mod, APQ_slap.ind.mod, APQ_Belt.ind.mod,
             CBCL_int.ind.mod, CBCL_ext.ind.mod, GHQ.health.ind.mod, ASSIST_alc.ind.mod, PSISF_stress.ind.mod, CTS_IPV.ind.mod)
round(pval,3)