#The purpose of this script is to reproduce Touwsranten paper 2 analyses
#08 MARCH 2023
#Paper 2 descriptives for waves 3-5

#One hash is used to comment {#}
#Double hashes are used to indicate where the user must insert of adjust code {##}
#Multiple consecutive hashes (>2) are used to separate sections of the script {###################################################################}

####################################################################################################################################################
#The major aim of this study is to assess community-wide change in positive parenting and use of corporal punishment across 3 waves from 2016 to 2019, 
#a period which coincides with the introduction of parenting interventions within the Touwsranten community, which were first rolled out in 2017.
#Secondary aims of this study include assessing (1) community-wide change in problem child behaviour and (2) parental stress, as well as assessing whether (3) child-reports of parenting coincided with parent-reports

#Longitudinal growth curve mixed-effects models were used to model the trajectory of parenting, child behaviours and parent stress over time, where for each major outcome of interest,two levels of analysis were conducted:

#1. Level 1 analysis modelled outcome trajectory on the entire community sample, including dropout and late-entry participants. Note that for cases where there was dependency across dyads (i.e. same parent-different child, same child-different parent, previous child as new parent), these cases were removed (approximately 4% of entire sample)
#2. Level 2 analysis modelled outcome trajectory on a subset of the larger sample, whom participated in all 3 waves
####################################################################################################################################################

#Preamble settings
rm(list=ls())
library(pacman)
p_load(tidyverse, readxl, ggplot2, knitr, ggcorrplot, psych, markdown,prettydoc, nlme, Rmisc, gridExtra, lme4, kableExtra, 
       sjPlot, lmerTest,semTools, gtsummary, nonpar, rstatix)
#Set current directory
##setwd()

#Import Touwsranten dataset (waves 1-5), and filter waves 3-5
Independentdyads_Waves3to5=read.csv("W1W2W3W4W5_Touwsranten.dataset.v1.csv")%>%
  filter(Wave == 3|Wave == 4 | Wave == 5)%>%
  mutate_at(vars(ParentsID,ChildsID), ~as.character(.))%>%
  #Remove dependent observations ((1) same child, different parents or (2) same parent, different child)
  filter(!(str_detect(ParentsID,".2$")|str_detect(ChildsID,".2$")))%>%
  ungroup()

#Filter out wave 3 where data is missing. E.g., APQ & PARYC corporal punishment items, and social acitivation items
Independentdyads_Waves4to5 = Independentdyads_Waves3to5%>%
  filter(Wave ==4 | Wave == 5)

#Child-reported parenting data not included here (Only administered to a subset, N = 86 children)

#######################################################################################################################################
#Reliability checks (cronbach's alpha)

#APQ total score
APQ.reliability <-
  '
APQ_total =~ FriendlyTalk.APQ+SpecialActivities.APQ+ PlayGames.APQ+ AskAboutSchool.APQ+ HomeworkHelp.APQ+AskAboutPlans.APQ+TakesToActivity.APQ+
TalkAboutFriends.APQ+PlanningFamilyActivities.APQ+AttendsMeetings.APQ+ GoodJob.APQ+RewardBehaviour.APQ+Compliments.APQ+PraiseBehaviour.APQ+HugsKisses.APQ+ 
LikesHelp.APQ+ LeavesNote.APQ+StaysOutTooLate.APQ+DoNotKnowFriends.APQ+NoCurfew.APQ+OutLateWithoutAdult.APQ+ForgetChild.APQ+CheckHomeTime.APQ+
TellChildYourWhereabouts.APQ+LateFromSchool.APQ+HomeSupervision.APQ+ThreatenPunishment.APQ+NegotiatePunishment.APQ+Obedience.APQ+LetOutPunishment.APQ+
PunishesBehaviour.APQ+PunishmentMood.APQ
'
APQ.fit = cfa(APQ.reliability, data = Independentdyads_Waves3to5)
APQ_parenting=reliability(APQ.fit)[1:2,1]

#APQ involvement subscale
APQ.Involvement_reliability <-
  '
APQ_Involvement =~ FriendlyTalk.APQ+SpecialActivities.APQ+ PlayGames.APQ+ AskAboutSchool.APQ+ HomeworkHelp.APQ+AskAboutPlans.APQ+TakesToActivity.APQ+
TalkAboutFriends.APQ+PlanningFamilyActivities.APQ+AttendsMeetings.APQ
'
APQ.Involvement_fit = cfa(APQ.Involvement_reliability, data = Independentdyads_Waves3to5)
APQ.Involvement_parenting=reliability(APQ.Involvement_fit)[1:2,1]

#APQ positive parenting subscale
APQ.PosPar_reliability <-
  '
APQ_PosPar =~ GoodJob.APQ+RewardBehaviour.APQ+Compliments.APQ+PraiseBehaviour.APQ+HugsKisses.APQ+ LikesHelp.APQ
'
APQ.PosPar_fit = cfa(APQ.PosPar_reliability, data = Independentdyads_Waves3to5)
APQ.PosPar_parenting=reliability(APQ.PosPar_fit)[1:2,1]

#APQ poor monitoring subscale
APQ.PoorMon_reliability <-
  '
APQ_PoorMon =~ LeavesNote.APQ+StaysOutTooLate.APQ+DoNotKnowFriends.APQ+NoCurfew.APQ+OutLateWithoutAdult.APQ+ForgetChild.APQ+CheckHomeTime.APQ+
TellChildYourWhereabouts.APQ+LateFromSchool.APQ+HomeSupervision.APQ
'
APQ.PoorMon_fit = cfa(APQ.PoorMon_reliability, data = Independentdyads_Waves3to5)
APQ.PoorMon_parenting=reliability(APQ.PoorMon_fit)[1:2,1]

#APQ inconsistent discipline subscale
APQ.InconDiscipline_reliability <-
  '
APQ_InconDiscipline =~ ThreatenPunishment.APQ+NegotiatePunishment.APQ+Obedience.APQ+LetOutPunishment.APQ+PunishesBehaviour.APQ+PunishmentMood.APQ
'
APQ.InconDiscipline_fit = cfa(APQ.InconDiscipline_reliability, data = Independentdyads_Waves3to5)
APQ.InconDiscipline_parenting=reliability(APQ.InconDiscipline_fit)[1:2,1]

#APQ corporal punishment subscale
APQ.corp.reliability <-
  '
APQ_CorpPun =~ SpankHand.APQ+SlapChild.APQ+HitsWithBelt.APQ
'
APQ.corp.fit = cfa(APQ.corp.reliability, data = Independentdyads_Waves4to5)
APQ_corporal_punishment=reliability(APQ.corp.fit)[1:2,1]

#PARYC total 
PARYC.reliability <-
  '
PARYC_total =~ FunPlay.PARYC+ProblemSolving.PARYC+ PlayGame.PARYC+ PraiseBehaviour.PARYC+ TeachNewSkills.PARYC+HouseholdChores.PARYC+ RewardNewSkill.PARYC+ 
StickToRules.PARYC+SpeakCalmly.PARYC+ClearExplanation.PARYC+TellChildToDo.PARYC+ BehaviouralExpectations.PARYC+SetRules.PARYC+FollowedRules.PARYC
'
PARYC.fit = cfa(PARYC.reliability, data = Independentdyads_Waves3to5)
PARYC_parenting=reliability(PARYC.fit)[1:2,1]

#PARYC corporal punishment subscale
PARYC.corp.reliability <-
  '
PARYC_CorpPun =~ SpankChild.PARYC+SlapChild.PARYC+HitChild.PARYC
'
PARYC.corp.fit = cfa(PARYC.corp.reliability, data = Independentdyads_Waves4to5)
PARYC_corporal_punishment= reliability(PARYC.corp.fit)[1:2,1]

#Parent stress total
PSISF.reliability <-
  '
PSISF_Total_ParentStress =~ NotHandle.PSISF+GivingMore.PSISF+Trapped.PSISF+
    UnableNewThings.PSISF+UnableTodoThingsILike.PSISF+ClothingPurchaseUnhappy.PSISF+
    ThingsBother.PSISF+RelationshipProblem.PSISF+Lonely.PSISF+PartyNotEnjoy.PSISF+
    NoInterestPeople.PSISF+NoEnjoyment.PSISF+ChildNotMakeFeelGood.PSISF+
    ChildDislikesMe.PSISF+ChildSmilesLess.PSISF+ChildUnappreciative.PSISF+
    ChildNotLaugh.PSISF+ChildSlowLearnOthers.PSISF+ChildSmileLessOthers.PSISF+
    ChildDoLess.PSISF+ChildSlowAdapt.PSISF+Parent.PSISF+WarmerFeelingsToChild.PSISF+
    ChildDoesThings.PSISF+ChildCryFuss.PSISF+ChildWakesBadMood.PSISF+ChildVeryMoody.PSISF+
    ChildThingsBotherMe.PSISF+ChildReactsStrongly.PSISF+ChildUpsetEasily.PSISF+
    ChildSleepingEating.PSISF+GettingChildToDoSomething.PSISF+CountThingsThatBother.PSISF+
    ChildDoesBotherALot.PSISF+ChildMoreProblem.PSISF+ChildDemands.PSISF
'
PSISF.fit = cfa(PSISF.reliability, data = Independentdyads_Waves3to5)
PSISF_parental_stress=reliability(PSISF.fit)[1:2,1]

#Conflict tactics scale
CTS.reliability <-
  '
CTS_IPV =~ PartnerInsultedSwore.CTS+IInsultedSwore.CTS+PartnerThrew.CTS+IThrew.CTS+
    PartnerTwisted.CTS+ITwisted.CTS+PartnerPushed.CTS+IPushed.CTS+PartnerKnifeGun.CTS+
    IKnifeGun.CTS+PartnerPunchedHit.CTS+IPunchedHit.CTS+PartnerChoked.CTS+IChoked.CTS+
    PartnerShoutedYelled.CTS+IShoutedYelled.CTS+PartnerSlammed.CTS+ISlammed.CTS+
    PartnerBeat.CTS+IBeat.CTS+PartnerGrabbed.CTS+IGrabbed.CTS+PartnerStomped.CTS+
    IStomped.CTS+PartnerSlapped.CTS+ISlapped.CTS+PartnerBurnedScalded.CTS+
    IBurnedScalded.CTS+PartnerSpite.CTS+ISpite.CTS+PartnerKickedBitPunched.CTS+
    IKickedBitPunched.CTS
'
CTS.fit = cfa(CTS.reliability, data = Independentdyads_Waves3to5)
CTS_Intimate_partner_violence=reliability(CTS.fit)[1:2,1]

#CBCL Internalising subscale (6-18 year)
CBCL.Older.Internal.reliability <-
  '
CBCL_Older_Internalising =~ CriesALot6to18.CBC+FearsOtherThanSchool6to18.CBC+
    FearsSchool6to18.CBC+FearsDoingBad6to18.CBC+NeedForPerfection6to18.CBC+ComplainNoLove6to18.CBC+
    FeelsInferior6to18.CBC+NervousTense6to18.CBC+ FearfulAnxious6to18.CBC+ TooGuilty6to18.CBC+
    SelfconciousEasilyEmbarrassed6to18.CBC+ SuicideTalk6to18.CBC+Worries6to18.CBC+ Nightmares6to18.CBC+Constipated6to18.CBC+
    DizzyLightheaded6to18.CBC+ Overtired6to18.CBC+ AchesPains6to18.CBC+ 
    Headaches6to18.CBC+Nausea6to18.CBC+EyeProblems6to18.CBC+SkinRashes6to18.CBC+StomachAches6to18.CBC+ Vomiting6to18.CBC+ VeryLittleEnjoyment6to18.CBC+PrefersBeingAlone6to18.CBC+
    RefuseToTalk6to18.CBC+Secretive6to18.CBC+ShyTimid6to18.CBC+UnderactiveLacksEnergy6to18.CBC+
    UnhappyDepressed6to18.CBC+ Withdrawn6to18.CBC
'
CBCL.Older.Internal.fit = cfa(CBCL.Older.Internal.reliability, data = Independentdyads_Waves3to5)
CBCL_Internalising_older=reliability(CBCL.Older.Internal.fit)[1:2,1]

#CBCL Externalising subscale (6-18 year)
CBCL.Older.External.reliability <-
  '
CBCL_Older_Externalising =~ ArguesALot6to18.CBC+CrueltyToOthers6to18.CBC+ 
    DemandsAttention6to18.CBC+ DestroysOwnThings6to18.CBC+ DestroysOthersThings6to18.CBC+ 
    DisobedientAtHome6to18.CBC+ DisobedientAtSchool6to18.CBC+ InManyFights6to18.CBC+ 
    PhysicallyAttacks6to18.CBC+ ScreamsFrequently6to18.CBC+ StubbornSullenIrritable6to18.CBC+
    ChangedMoods6to18.CBC+ Sulks6to18.CBC+ Suspicious6to18.CBC+ TeasesALot6to18.CBC+ 
    TemperTantrums6to18.CBC+ ThreatensPeople6to18.CBC+ UnusuallyLoud6to18.CBC+ AlcoholWithoutApproval6to18.CBC+ 
    GuiltAfterMisbehaving6to18.CBC+BreaksRules6to18.CBC+TroubleMakerFriends6to18.CBC+
    LyingCheating6to18.CBC+PrefersOlderKids6to18.CBC+RunsAway6to18.CBC+ SetsFires6to18.CBC+ 
    SexualProblems6to18.CBC+ StealsAtHome6to18.CBC+StealsOutsideHome6to18.CBC+Swearing6to18.CBC+
    ObsessedWithSex6to18.CBC+ SmokesTobacco6to18.CBC+ Truancy6to18.CBC+UsesDrugs6to18.CBC+Vandalism6to18.CBC
'
CBCL.Older.External.fit = cfa(CBCL.Older.External.reliability, data = Independentdyads_Waves3to5)
CBCL_Externalising_older=reliability(CBCL.Older.External.fit)[1:2,1]

#CBCL Internalising subscale (1.5-5 year)
CBCL.Young.Internal.reliability <-
  '
CBCL_Younger_Internalising =~ ChangeInRoutine185.CBC+NervousMovements185.CBC+
    ShowsPanic185.CBC+MoodShift185.CBC+FeelingsChange185.CBC+Sulks185.CBC+
    UpsetByNew185.CBC+Whining185.CBC+Worries185.CBC+ClingsDependent185.CBC+HurtFeelings185.CBC+
    UpsetWhenSeparated185.CBC+LooksUnhappy185.CBC+Nervous185.CBC+Selfconscious185.CBC+
    TooAnxious185.CBC+Unhappy185.CBC+ AchesPains185.CBC+ThingsOutPlace185.CBC+
    Constipated185.CBC+Diarrhea185.CBC+EatBadly185.CBC+Headaches185.CBC+Nausea185.CBC+
    PainfulBowel185.CBC+Stomachaches185.CBC+Neatness185.CBC+Vomiting185.CBC+ ActsTooYoung185.CBC+AvoidsEyeContact185.CBC+Ignore185.CBC+
    RefuseActiveGame185.CBC+UnresponsiveAffect185.CBC+LittleAffection185.CBC+
    LittleInterest185.CBC+Withdrawn185.CBC
'
CBCL.Young.Internal.fit = cfa(CBCL.Young.Internal.reliability, data = Independentdyads_Waves3to5)
CBCL_Internalising_younger =reliability(CBCL.Young.Internal.fit)[1:2,1]

#CBCL Externalising subscale (1.5-5 year)
CBCL.Young.External.reliability <-
  '
CBCL_Younger_Externalising =~ Concentrate185.CBC+SitStill185.CBC+Clumsy185.CBC+
    ShiftActivity185.CBC+Wanders185.CBC+ Impatient185.CBC+Defiant185.CBC+Demands185.CBC+
    DestroysOthersThings185.CBC+Disobedient185.CBC+NotGuilty185.CBC+Frustrated185.CBC+
    Fights185.CBC+HitsOthers185.CBC+HurtsAnimalsPeople185.CBC+AngryMoods185.CBC+
    PhysicallyAttacks185.CBC+PunishmentNoEffect185.CBC+Screams185.CBC+Selfish185.CBC+
    Stubborn185.CBC+TemperTantrum185.CBC+Uncooperative185.CBC+WantsAttention185.CBC
'
CBCL.Young.External.fit = cfa(CBCL.Young.External.reliability, data = Independentdyads_Waves3to5)
CBCL_Externalising_younger =reliability(CBCL.Young.External.fit)[1:2,1]

#Mental health total
GHQ.reliability <-
  '
GHQ_GeneralHealth =~ WellGoodHealth.GHQ+NeedGoodTonic.GHQ+RunDown.GHQ+FeltIll.GHQ+
    PainsInHead.GHQ+TightnessInHead.GHQ+HotColdSpells.GHQ+LostSleepWorry.GHQ+
    CantStayAsleep.GHQ+UnderStrain.GHQ+BadTempered.GHQ+ScaredPanicky.GHQ+GettingOnTop.GHQ+
    NervousStrungUp.GHQ+StayBusy.GHQ+TakingLonger.GHQ+DoingThingsWell.GHQ+
    SatisfiedTasks.GHQ+UsefulPart.GHQ+MakingDecisions.GHQ+EnjoyDailyActivities.GHQ+
    Worthless.GHQ+Hopeless.GHQ+LifeNotWorthLiving.GHQ+Suicide.GHQ+
    CantDoAnythingNerves.GHQ+WishingDead.GHQ+TakingOwnLife.GHQ
'
GHQ.fit = cfa(GHQ.reliability, data = Independentdyads_Waves3to5)
GHQ_General_health=reliability(GHQ.fit)[1:2,1]

#ASSIST alcohol subscale
ASSIST.reliability <-
  '
ASSIST_AlcoholSeverity =~ UsedAlcoholThreeMonths.ASSIST+UrgeAlcoholThreeMonths.ASSIST+
    AlcoholProblemsThreeMonths.ASSIST+AlcoholFailedToDoThreeMonths.ASSIST+FriendRelativeConcerned.ASSIST+
    ControlStopAlcoholUse.ASSIST
'
ASSIST.fit = cfa(ASSIST.reliability, data = Independentdyads_Waves3to5)
ASSIST_Alcohol_use=reliability(ASSIST.fit)[1:2,1]

#Social activation: Program indirect involvement subscale
SA.reliability <-
  '
Program_Indirect_Involvement =~ SocialActivation.1+SocialActivation.2+SocialActivation.3+
    SocialActivation.4+SocialActivation.5+SocialActivation.6+SocialActivation.7+SocialActivation.8+
    SocialActivation.9+SocialActivation.10+SocialActivation.11+SocialActivation.12
'
SA.fit = cfa(SA.reliability, data = Independentdyads_Waves4to5)
SA_Program_indirect_involvement=reliability(SA.fit)[1:2,1]

#Social activation: Community involvement subscale
SA2.reliability <-
  '
Community_Involvement =~ SocialActivation.13+SocialActivation.14+SocialActivation.15+
    SocialActivation.16
'
SA2.fit = cfa(SA2.reliability, data = Independentdyads_Waves4to5)
SA_Community_involvement=reliability(SA2.fit)[1:2,1]

#Collate and print reliability estimates
reliable=rbind(APQ_parenting,APQ.Involvement_parenting,APQ.PosPar_parenting, APQ.PoorMon_parenting, APQ.InconDiscipline_parenting, APQ_corporal_punishment, 
               PARYC_corporal_punishment, PSISF_parental_stress, CTS_Intimate_partner_violence, CBCL_Internalising_younger, CBCL_Externalising_younger, 
               CBCL_Internalising_older, CBCL_Externalising_older, GHQ_General_health, ASSIST_Alcohol_use, SA_Program_indirect_involvement, SA_Community_involvement)
reliable
#Note: Reliability of APQ inconsistent discipline & corporal punishment (both APQ & PARYC) is < .70

####################################################################################################################################################
#Descriptives (for waves 3-5)

All.descriptives = Independentdyads_Waves3to5%>%
  dplyr::select(Wave,ChildGender, ChildAge, ParentGender,ParentAge,EmploymentStatus.DEMOGRAPHICS, MaritalStatus.2lvl.DEMOGRAPHICS,
                Parenting_total.Zscore.FINAL, SpankHand.Comp,SlapChild.Comp, HitChild.Comp, CBCL_Internalising.tscore,
                CBCL_Internalising.Threshold,CBCL_Externalising.tscore,CBCL_Externalising.Threshold,GHQ_GeneralHealth.subsc,
                GHQ_GeneralHealth.Threshold, ASSIST_AlcoholSeverity.subsc,ASSIST_AlcoholSeverity.Threshold, PSISF_Total_ParentStress.subsc,
                PSISF_Total_ParentStress.percentile,CTS_IPV.subsc,CTS_IPV_categorical,SA_Program_indirect_engagement, SA_Community_engagement)%>%
  mutate_at(vars(SpankHand.Comp, SlapChild.Comp,HitChild.Comp, SA_Community_engagement), ~as.numeric(.))

gtsummary::tbl_summary(All.descriptives, digits = list( ~ c(2, 2)), 
            missing = "no", by = Wave, 
            statistic = list(all_continuous() ~ "{mean} ({sd})"),
            type =  list(EmploymentStatus.DEMOGRAPHICS ~ "categorical",
                         MaritalStatus.2lvl.DEMOGRAPHICS ~ "categorical",
                         GHQ_GeneralHealth.Threshold ~ "categorical",
                         SpankHand.Comp ~ "continuous",
                         SlapChild.Comp ~ "continuous",
                         HitChild.Comp ~ "continuous",
                         SA_Community_engagement ~ "continuous")) %>%
  bold_labels() %>% 
  modify_header(label = "**Variable**")

####################################################################################################################################################
