#The purpose of this script is to reproduce Touwsranten paper 2 analyses
#08 MARCH 2023
#Paper 2 graphics

#One hash is used to comment {#}
#Double hashes are used to indicate where the user must insert of adjust code {##}
#Multiple consecutive hashes (>2) are used to separate sections of the script {###################################################################}

####################################################################################################################################################
#The major aim of this study is to assess community-wide change in positive parenting and use of corporal punishment across 3 waves from 2016 to 2019, 
#a period which coincides with the introduction of parenting interventions within the Touwsranten community, which were first rolled out in 2017.
#Secondary aims of this study include assessing (1) community-wide change in problem child behaviour and (2) parental stress, as well as assessing whether (3) child-reports of parenting coincided with parent-reports

#Longitudinal growth curve mixed-effects models were used to model the trajectory of parenting, child behaviours and parent stress over time, where for each major outcome of interest,two levels of analysis were conducted:

#1. Level 1 analysis modelled outcome trajectory on the entire community sample, including dropout and late-entry participants. Note that for cases where there was dependency across dyads (i.e. same parent-different child, same child-different parent, previous child as new parent), these cases were removed (approximately 4% of entire sample)
#2. Level 2 analysis modelled outcome trajectory on a subset of the larger sample, whom participated in all 3 waves
####################################################################################################################################################

#Preamble settings
rm(list=ls())
library(pacman)
p_load(tidyverse, readxl, ggplot2, knitr, ggcorrplot, psych, markdown,prettydoc, nlme, Rmisc, gridExtra, lme4, kableExtra, 
       sjPlot, lmerTest,semTools, gtsummary, nonpar, rstatix)
#Set current directory
##setwd()

#Import Touwsranten dataset (waves 1-5), and filter waves 3-5
Independentdyads_Waves3to5=read.csv("W1W2W3W4W5_Touwsranten.dataset.v1.csv")%>%
  filter(Wave == 3|Wave == 4 | Wave == 5)%>%
  mutate_at(vars(ParentsID,ChildsID), ~as.character(.))%>%
  #Remove dependent observations ((1) same child, different parents or (2) same parent, different child)
  filter(!(str_detect(ParentsID,".2$")|str_detect(ChildsID,".2$")))%>%
  ungroup()

#Prepare data for graphics 
FullSample = Independentdyads_Waves3to5%>%
  dplyr::select(UniqueDyadID, ParentChildID, Wave, ChildAge, ChildGender,
                "Positive parenting (Zscore)" =Parenting_total.Zscore.FINAL,
                "Problematic alcohol use"= ASSIST_AlcoholSeverity.subsc,
                "Poor general health" =GHQ_GeneralHealth.subsc, 
                "Parental stress" =  PSISF_Total_ParentStress.subsc,
                "Intimate partner violence" = CTS_IPV.subsc,
                "Internalising behaviour" =CBCL_Internalising.tscore,
                "Externalising behaviour"=CBCL_Externalising.tscore)

#Filter out wave 3 where data is missing. E.g., APQ & PARYC corporal punishment items, and social acitivation items
Independentdyads_Waves4to5 = Independentdyads_Waves3to5%>%
  filter(Wave ==4 | Wave == 5)

##################################################################################################################
#Unadjusted trajectory graphics
##################################################################################################################

Parenting.TA<-summarySE(FullSample, measurevar="Positive parenting (Zscore)", groupvars=c("Wave"), na.rm = TRUE)
Stress<-summarySE(FullSample, measurevar="Parental stress", groupvars=c("Wave"), na.rm = TRUE)
Internal<-summarySE(FullSample, measurevar="Internalising behaviour", groupvars=c("Wave"), na.rm = TRUE)
External<-summarySE(FullSample, measurevar="Externalising behaviour", groupvars=c("Wave"), na.rm = TRUE)
IPV<-summarySE(FullSample, measurevar="Intimate partner violence", groupvars=c("Wave"), na.rm = TRUE)
PoorHealth<-summarySE(FullSample, measurevar="Poor general health", groupvars=c("Wave"), na.rm = TRUE)
Alcohol<-summarySE(FullSample, measurevar="Problematic alcohol use", groupvars=c("Wave"), na.rm = TRUE)

Parent=Parenting.TA%>% 
  mutate(Wave = as.factor(Wave))%>%
  ggplot(aes(x = Wave, y = `Positive parenting (Zscore)`, group = 1))+
  geom_line(size=1.1, color = "#F8766D")+
  geom_errorbar(aes(ymin=`Positive parenting (Zscore)`-se, ymax=`Positive parenting (Zscore)`+se), 
                size=1.1,width=.5, color = "#F8766D")+
  ggtitle("Positive parenting")+
  geom_point(size = 4, color = "#F8766D")+
  theme_classic()

Internal=Internal%>% 
  mutate(Wave = as.factor(Wave))%>%
  ggplot(aes(x = Wave, y = `Internalising behaviour`), group = 1)+
  geom_line(size=1.1, color = "#00B6EB", group = 1)+
  geom_errorbar(aes(ymin=`Internalising behaviour`-se, ymax=`Internalising behaviour`+se), 
                size=1.1,width=.5, color = "#00B6EB")+
  ggtitle("Internalising behaviours")+
  geom_point(size = 4, color = "#00B6EB")+
  theme_classic()

External=External%>% 
  mutate(Wave = as.factor(Wave))%>%
  ggplot(aes(x = Wave, y = `Externalising behaviour`),group = 1)+
  geom_line(size=1.1, color = "#A58AFF", group = 1)+
  geom_errorbar(aes(ymin=`Externalising behaviour`-se, ymax=`Externalising behaviour`+se),
                size=1.1,width=.5, color = "#A58AFF")+
  ggtitle("Externalising behaviour")+
  geom_point(size = 4, color = "#A58AFF")+
  theme_classic()

Stress=Stress%>% 
  mutate(Wave = as.factor(Wave))%>%
  ggplot(aes(x = Wave, y = `Parental stress`),group = 1)+
  geom_line(size=1.1, color = "#53B400", group = 1)+
  geom_errorbar(aes(ymin=`Parental stress`-se, ymax=`Parental stress`+se), 
                size=1.1,width=.5, color = "#53B400")+
  ggtitle("Parental stress")+
  geom_point(size = 4, color = "#53B400")+
  theme_classic()

IPV = IPV %>%
  mutate(Wave = as.factor(Wave))%>%
  ggplot(aes(x = Wave, y = `Intimate partner violence`),group = 1)+
  geom_line(size=1.1, color = "#C49A00", group = 1)+
  geom_errorbar(aes(ymin=`Intimate partner violence`-se, ymax=`Intimate partner violence`+se), 
                size=1.1,width=.5, color = "#C49A00")+
  geom_point(color = "#C49A00")+
  ggtitle("Intimate partner violence")+
  geom_point(size = 4, color = "#C49A00")+
  theme_classic()

PoorHealth = PoorHealth %>%
  mutate(Wave = as.factor(Wave))%>%
  ggplot(aes(x = Wave, y = `Poor general health`),group = 1)+
  geom_line(size=1.1, color = "#00C094", group = 1)+
  geom_errorbar(aes(ymin=`Poor general health`-se, ymax=`Poor general health`+se), 
                size=1.1,width=.5, color = "#00C094")+
  ggtitle("Poor mental health")+
  geom_point(size = 4, color = "#00C094")+
  theme_classic()

Alcohol = Alcohol %>%
  mutate(Wave = as.factor(Wave))%>%
  ggplot(aes(x = Wave, y = `Problematic alcohol use`),group = 1)+
  geom_line(size=1.1, color = "#FB61D7", group = 1)+
  geom_errorbar(aes(ymin=`Problematic alcohol use`-se, ymax=`Problematic alcohol use`+se), 
                size=1.1,width=.5, color = "#FB61D7")+
  ggtitle("Risk of Alcohol Use Disdorder")+
  geom_point(size = 4, color = "#FB61D7")+
  theme_classic()

grid.arrange(Parent, Stress,Internal, External, IPV, PoorHealth, Alcohol, nrow = 1)

##################################################################################################################
#Adjusted trajectory graphics: Outcome variables
##################################################################################################################

Graph = FullSample%>%
  dplyr::rename("Positive parenting" = `Positive parenting (Zscore)`)%>%
  mutate(`Parental stress` = scale(`Parental stress`))%>%
  mutate(`Internalising behaviour` = scale(`Internalising behaviour`))%>%
  mutate(`Externalising behaviour` = scale(`Externalising behaviour`))%>%
  dplyr::select(UniqueDyadID, Wave, `Positive parenting`, `Parental stress`,
                `Internalising behaviour`, `Externalising behaviour`)%>%
  reshape2::melt(id.vars= c("UniqueDyadID", "Wave"))%>%
  filter(!is.na(value))%>%
  mutate(Wave = as.factor(Wave))%>%
  mutate(variable = as.factor(variable))

Graph.means = summarySE(Graph, measurevar="value",groupvars=c("variable","Wave"))

Gjpeg=Graph.means %>%
  ggplot(aes(x = Wave, y = value, group= variable, colour = variable))+
  geom_line(size = 2)+
  geom_point(size=4)+
  labs(colour = "Variables")+
  theme_classic()+
  ylab("Scaled score")+
  theme(legend.text=element_text(size=12))+
  theme(legend.title=element_text(size=14))+
  theme(axis.title =element_text(size=12))+
  theme(axis.text.x =element_text(size=12), axis.text.y = element_text(size=12))+
  ggtitle("Outcome variables")
Gjpeg

##################################################################################################################
#Adjusted trajectory graphics: Covariate variables
##################################################################################################################

Graph2 = FullSample%>%
  mutate(`Intimate partner violence` = scale(`Intimate partner violence`))%>%
  mutate(`Poor general health` = scale(`Poor general health`))%>%
  mutate(`Problematic alcohol use` = scale(`Problematic alcohol use`))%>%
  dplyr::select(UniqueDyadID, Wave, `Intimate partner violence`, "Poor mental health" =`Poor general health`, "Risk of Alcohol Use Disorder" =`Problematic alcohol use`,)%>%
  reshape2::melt(id.vars= c("UniqueDyadID", "Wave"))%>%
  filter(!is.na(value))%>%
  mutate(Wave = as.factor(Wave))%>%
  mutate(variable = as.factor(variable))

group.colors <- c(`Intimate partner violence` = "#C49A00", `Poor general health` = "#00C094", 
                  `Problematic alcohol use` ="#FB61D7")

Graph2.means = summarySE(Graph2, measurevar="value",groupvars=c("variable","Wave"))

Gjpeg2=Graph2.means %>%
  ggplot(aes(x = Wave, y = value, group= variable, colour = variable))+
  geom_line(size = 2)+
  geom_point(size=4)+
  labs(colour = "Variables")+
  theme_classic()+
  ylab("Scaled score")+
  ylim(-0.4, 0.3)+
  theme(legend.text=element_text(size=12))+
  theme(legend.title=element_text(size=14))+
  theme(axis.title =element_text(size=12))+
  theme(axis.text.x =element_text(size=12), axis.text.y = element_text(size=12))+
  ggtitle("Covariates")+
  scale_colour_manual(values = c("#C49A00", "#00C094", "#FB61D7"))
Gjpeg2