#The purpose of this script is to reproduce Touwsranten paper 2 analyses
#08 MARCH 2023
#Paper 2 inferential statistics

#One hash is used to comment {#}
#Double hashes are used to indicate where the user must insert of adjust code {##}
#Multiple consecutive hashes (>2) are used to separate sections of the script {###################################################################}

####################################################################################################################################################
#The major aim of this study is to assess community-wide change in positive parenting and use of corporal punishment across 3 waves from 2016 to 2019, 
#a period which coincides with the introduction of parenting interventions within the Touwsranten community, which were first rolled out in 2017.
#Secondary aims of this study include assessing (1) community-wide change in problem child behaviour and (2) parental stress, as well as assessing whether (3) child-reports of parenting coincided with parent-reports

#Longitudinal growth curve mixed-effects models were used to model the trajectory of parenting, child behaviours and parent stress over time, where for each major outcome of interest,two levels of analysis were conducted:

#1. Level 1 analysis modelled outcome trajectory on the entire community sample, including dropout and late-entry participants. Note that for cases where there was dependency across dyads (i.e. same parent-different child, same child-different parent, previous child as new parent), these cases were removed (approximately 4% of entire sample)
#2. Level 2 analysis modelled outcome trajectory on a subset of the larger sample, whom participated in all 3 waves
####################################################################################################################################################

#Preamble settings
rm(list=ls())
library(pacman)
p_load(tidyverse, readxl, ggplot2, knitr, ggcorrplot, psych, markdown,prettydoc, nlme, Rmisc, gridExtra, lme4, kableExtra, 
       sjPlot, lmerTest,semTools, gtsummary, nonpar, rstatix,rmcorr)
#Set current directory
##setwd()

#Import Touwsranten dataset (waves 1-5), and filter waves 3-5
Independentdyads_Waves3to5=read.csv("W1W2W3W4W5_Touwsranten.dataset.v1.csv")%>%
  filter(Wave == 3|Wave == 4 | Wave == 5)%>%
  mutate_at(vars(ParentsID,ChildsID), ~as.character(.))%>%
  #Remove dependent observations ((1) same child, different parents or (2) same parent, different child)
  filter(!(str_detect(ParentsID,".2$")|str_detect(ChildsID,".2$")))%>%
  ungroup()

#Transform outcome variables so that they can undergo log transformation (ensure that scores begin at 1)
FullSample =Independentdyads_Waves3to5 %>%
  mutate(Parenting_total_log = 4.53+Parenting_total.Zscore.FINAL)%>%
  mutate(CorpPun_total_log = 2.05+CorpPun_total.Zscore)%>%
  mutate(GHQ_GeneralHealth_log = 1+GHQ_GeneralHealth.subsc)%>%
  mutate(ASSIST_AlcoholSeverity_log = 1+ASSIST_AlcoholSeverity.subsc)%>%
  mutate(CTS_IPV_log = 1+CTS_IPV.subsc)%>%
  dplyr::select(UniqueDyadID, ParentChildID, Wave, ChildAge, ChildGender,
                "Positive parenting (Zscore)" =Parenting_total.Zscore.FINAL,
                "Problematic alcohol use"= ASSIST_AlcoholSeverity.subsc,
                "Poor general health" =GHQ_GeneralHealth.subsc, 
                "Parental stress" =  PSISF_Total_ParentStress.subsc,
                "Intimate partner violence" = CTS_IPV.subsc,
                "Internalising behaviour" =CBCL_Internalising.tscore,
                "Externalising behaviour"=CBCL_Externalising.tscore,
                "Spank hand"= SpankHand.Comp, 
                "Slap child"= SlapChild.Comp, 
                "Hit child"= HitChild.Comp,
                "Positive parenting (log)" =Parenting_total_log,
                "Corporal punishment (log)"= CorpPun_total_log, 
                "Poor general health (log)" = GHQ_GeneralHealth_log, 
                "Problematic alcohol use (log)" = ASSIST_AlcoholSeverity_log,
                "Intimate partner violence (log)" =CTS_IPV_log,
                "Program indirect engagement" = SA_Program_indirect_engagement,
                "Community engagement"= SA_Community_engagement,
                "Program/s attended" = AttendedProgramProp)%>%
  mutate(ChildGender = factor(ChildGender, levels = c(2,1)))

#Isolate to intervention period, waves 4 & 5, only those who partook in a parenting program
InterventionSample = FullSample %>%
 # filter(Wave != 3)%>%
  filter(!is.na(`Program/s attended`))

#Summarise parenting program and corporal punishment data
ParentProg_corpPun=InterventionSample%>%
  group_by(UniqueDyadID)%>%
  dplyr::filter(n() ==2)%>%
  ungroup()%>%
  group_by(UniqueDyadID, `Program/s attended`)%>%
  arrange(desc(`Program/s attended`))%>%
  ungroup()%>%
  arrange(UniqueDyadID)%>%
  distinct(UniqueDyadID,.keep_all = TRUE)%>%
  dplyr::select(UniqueDyadID, `Program/s attended`, `Spank hand`, `Slap child`, `Hit child`)

#Select dyads with data available at wave 4 (for corporal punishment analyses)
CorporalPun_Wave4=read.csv("W1W2W3W4W5_Touwsranten.dataset.v1.csv")%>%
  filter(Wave == 3|Wave == 4 | Wave == 5)%>%
  group_by(UniqueDyadID)%>%
  filter(n()==3)%>%
  filter(Wave== 4)%>%
  dplyr::select(UniqueDyadID, Wave, contains("Spank"), contains("SlapChild"), contains("HitsWith"), contains("HitChild"))

#Select dyads with data available at wave 5 (for corporal punishment analyses)
CorporalPun_Wave5=read.csv("W1W2W3W4W5_Touwsranten.dataset.v1.csv")%>%
  filter(Wave == 3|Wave == 4 | Wave == 5)%>%
  group_by(UniqueDyadID)%>%
  filter(n()==3)%>%
  filter(Wave== 5)%>%
  dplyr::select(UniqueDyadID, Wave, contains("Spank"), contains("SlapChild"), contains("HitsWith"), contains("HitChild"))

##################################################################################################################
#Inferential statistics of analytic sample (dyads across waves 3-5) 

######################################################################################
#The purpose of these analyses is to assess longitudinal trends in positive parenting, 
#parental stress, internalising and externalising behaviour
#Using longitudinal mixed-effects models
#Unadjusted and adjusted models presented
#Note: Linear growth models selected given convergence issues with non-linear growth models
######################################################################################

###################
#Positive parenting
###################

ParentingAll.Un<- lmer(`Positive parenting (log)` ~ Wave+  (1|UniqueDyadID), data= FullSample, REML =TRUE)
ParentingAll.Ad<- lmer(`Positive parenting (log)` ~ Wave + ChildGender + scale(ChildAge)+ scale(`Intimate partner violence`) + scale(`Poor general health`) + scale(`Problematic alcohol use`) + scale(`Parental stress`) +(1|UniqueDyadID), data= FullSample, REML =TRUE)
tab_model(ParentingAll.Un, ParentingAll.Ad, auto.label = FALSE, transform = "exp", dv.labels = c("Model 1 unadjusted: Positive parenting (Zscore)", "Model 2 adjusted: Positive parenting (Zscore)"), p.val = "kenward", file = "Positive_parenting.doc")

########################
#Internalising behaviour
########################

Internalising.Un= lmer(log(`Internalising behaviour`) ~ Wave+  (1|UniqueDyadID),control = lmerControl(optimizer = "bobyqa"), data= FullSample, REML =TRUE)
Internalising.Ad= lmer(log(`Internalising behaviour`) ~ Wave+ `Positive parenting (Zscore)` + ChildGender + scale(ChildAge)+ scale(`Intimate partner violence`) + scale(`Poor general health`) + scale(`Problematic alcohol use`) + scale(`Parental stress`) + (1|UniqueDyadID), data= FullSample, REML =TRUE)
tab_model(Internalising.Un, Internalising.Ad, auto.label = FALSE, transform = "exp", dv.labels = c("Model 1 unadjusted: Internalising behaviour", "Model 2 adjusted: Internalising behaviour"), p.val = "kenward", file = "Internalising.doc")

########################
#Externalising behaviour
########################

Externalising.Un= lmer(log(`Externalising behaviour`) ~ Wave+  (1|UniqueDyadID),control = lmerControl(optimizer = "bobyqa"), data= FullSample, REML =TRUE)
Externalising.Ad<- lmer(log(`Externalising behaviour`) ~ Wave+ `Positive parenting (Zscore)` + ChildGender + scale(ChildAge)+ scale(`Intimate partner violence`) + scale(`Poor general health`) + scale(`Problematic alcohol use`) + scale(`Parental stress`) +(1|UniqueDyadID), data= FullSample, REML =TRUE)
tab_model(Internalising.Un, Internalising.Ad, auto.label = FALSE, transform = "exp", dv.labels = c("Model 1 unadjusted: Externalising behaviour", "Model 2 adjusted: Externalising behaviour"), p.val = "kenward", file = "Externalising.doc")

########################
#Parental stress
########################

ParentStress.Un<- lmer(log(`Parental stress`) ~ Wave+  (1|UniqueDyadID), data= FullSample, REML =TRUE)
ParentStress.Ad<- lmer(log(`Parental stress`) ~ Wave+ `Positive parenting (Zscore)` +ChildGender + scale(ChildAge)+ scale(`Intimate partner violence`) + scale(`Poor general health`) + scale(`Problematic alcohol use`) + (1|UniqueDyadID), data= FullSample, REML =TRUE)
tab_model(ParentStress.Un, ParentStress.Ad, auto.label = FALSE, transform = "exp", dv.labels = c("Model 1 unadjusted: Parental stress", "Model 2 adjusted: Parental stress"), p.val = "kenward", file = "Parental_stress.doc")

##################################################################################################################
#Inferential statistics of parenting program and social activation data from waves 4-5 (intervention phase)

######################################################################################
#The purpose of these analyses is to assess whether social activation and program attendance 
#are associated with positive parenting, parental stress, internalising and externalising behaviour
#Using longitudinal mixed-effects models
#Unadjusted and adjusted models presented
#Note: Linear growth models selected given convergence issues with non-linear growth models
######################################################################################

###################
#Positive parenting
###################

Parenting.Unadjusted1<- lmer(`Positive parenting (log)` ~ factor(`Program/s attended`) + (1|UniqueDyadID), data= InterventionSample, REML =TRUE)
Parenting.Unadjusted2<- lmer(`Positive parenting (log)` ~ scale(`Program indirect engagement`)+ scale(`Community engagement`) + (1|UniqueDyadID), data= InterventionSample, REML =TRUE)
Parenting.Adjusted<- lmer(`Positive parenting (log)` ~ factor(`Program/s attended`) + scale(`Program indirect engagement`)+ scale(`Community engagement`)+ (1|UniqueDyadID), data= InterventionSample, REML =TRUE)
tab_model(Parenting.Unadjusted1,Parenting.Unadjusted2,Parenting.Adjusted, auto.label = FALSE,transform = "exp", dv.labels = c("Model 1 program attendance: Positive parenting (Zscore)", "Model 2 social activation: Positive parenting (Zscore)", "Model 3 combined: Positive parenting (Zscore)"), p.val = "kenward")

########################
#Internalising behaviour
########################

Internalising.Unadjusted1<- lmer(log(`Internalising behaviour`) ~ `Program/s attended` + (1|UniqueDyadID), data= InterventionSample, REML =TRUE)
Internalising.Unadjusted2<- lmer(log(`Internalising behaviour`) ~  scale(`Program indirect engagement`)+ scale(`Community engagement`)  + (1|UniqueDyadID), data= InterventionSample, REML =TRUE)
Internalising.Adjusted<- lmer(log(`Internalising behaviour`) ~ `Program/s attended` + scale(`Program indirect engagement`)+ scale(`Community engagement`)+ (1|UniqueDyadID), data= InterventionSample, REML =TRUE)
tab_model(Internalising.Unadjusted1,Internalising.Unadjusted2,Internalising.Adjusted, auto.label = FALSE, transform = "exp",dv.labels = c("Model 1 program attendance: Internalising", "Model 2 social activation: Internalising", "Model 3 combined: Internalising"), p.val = "kenward", file = "Internalising_SA.doc")

########################
#Externalising behaviour
########################

Externalising.Unadjusted1<- lmer(log(`Externalising behaviour`) ~ `Program/s attended` + (1|UniqueDyadID), data= InterventionSample, REML =TRUE)
Externalising.Unadjusted2<- lmer(log(`Externalising behaviour`) ~ scale(`Program indirect engagement`)+ scale(`Community engagement`) + (1|UniqueDyadID), data= InterventionSample, REML =TRUE)
Externalising.Adjusted<- lmer(log(`Externalising behaviour`) ~ `Program/s attended` + scale(`Program indirect engagement`)+ scale(`Community engagement`)+ (1|UniqueDyadID), data= InterventionSample, REML =TRUE)
tab_model(Externalising.Unadjusted1,Externalising.Unadjusted2,Externalising.Adjusted, auto.label = FALSE, transform = "exp", dv.labels = c("Model 1 program attendance: Externalising", "Model 2 social activation: Externalising", "Model 3 combined: Externalising"), p.val = "kenward", file = "Externalising_SA.doc")

########################
#Parental stress
########################

ParentStress.Unadjusted1<- lmer(log(`Parental stress`) ~ `Program/s attended` + (1|UniqueDyadID), data= InterventionSample, REML =TRUE)
ParentStress.Unadjusted2<- lmer(log(`Parental stress`) ~ scale(`Program indirect engagement`)+ scale(`Community engagement`) + (1|UniqueDyadID), data= InterventionSample, REML =TRUE)
ParentStress.Adjusted<- lmer(log(`Parental stress`) ~ `Program/s attended` + scale(`Program indirect engagement`)+ scale(`Community engagement`)+ (1|UniqueDyadID), data= InterventionSample, REML =TRUE)
tab_model(ParentStress.Unadjusted1,ParentStress.Unadjusted2,ParentStress.Adjusted, auto.label = FALSE,transform = "exp", dv.labels = c("Model 1 program attendance: Parent stress", "Model 2 social activation: Parent stress", "Model 3 combined: Parent stress"), p.val = "kenward", file = "Parental_stress_SA.doc")

###########################################################################################################
#The purpose of these analyses is to assess whether social activation and program attendance are associated
#Using linear regression models
###########################################################################################################

lm1=lm(`Program indirect engagement` ~ factor(`Program/s attended`), data = InterventionSample, alternative = "two.sided", conf.int = TRUE)
lm2=lm(`Community engagement` ~ factor(`Program/s attended`), data = InterventionSample, alternative = "two.sided", conf.int = TRUE)
tab_model(lm1,lm2,auto.label = FALSE, dv.labels = c("Model 1: Program attendance and program indirect engagement", "Model 2: Program attendance and community engagement"))

##################################################################################################################
#Inferential statistics of changes in corporal punishment between waves 4 and 5

######################################################################################################################################
#The purpose of these analyses is to assess corporal punishment trends and how they relate to social activation and program attendance
#Run wilcoxon signed ranked test to assess potential differences in corporal punishment over time
######################################################################################################################################

Spank.all.mod = wilcox.test(CorporalPun_Wave4$SpankHand.Comp, CorporalPun_Wave5$SpankHand.Comp, paired = TRUE)$p.value
Spank.young.mod = wilcox.test(CorporalPun_Wave4$SpankChild.PARYC, CorporalPun_Wave5$SpankChild.PARYC, paired = TRUE)$p.value
Spank.old.mod = wilcox.test(CorporalPun_Wave4$SpankHand.APQ, CorporalPun_Wave5$SpankHand.APQ, paired = TRUE)$p.value

Slap.all.mod = wilcox.test(CorporalPun_Wave4$SlapChild.Comp, CorporalPun_Wave5$SlapChild.Comp, paired = TRUE)$p.value
Slap.young.mod = wilcox.test(CorporalPun_Wave4$SlapChild.PARYC, CorporalPun_Wave5$SlapChild.PARYC, paired = TRUE)$p.value
Slap.old.mod = wilcox.test(CorporalPun_Wave4$SlapChild.APQ, CorporalPun_Wave5$SlapChild.APQ, paired = TRUE)$p.value

Hit.all.mod = wilcox.test(CorporalPun_Wave4$HitChild.Comp, CorporalPun_Wave5$HitChild.Comp, paired = TRUE)$p.value
Hit.young.mod = wilcox.test(CorporalPun_Wave4$HitChild.PARYC, CorporalPun_Wave5$HitChild.PARYC, paired = TRUE)$p.value
Hit.old.mod = wilcox.test(CorporalPun_Wave4$HitsWithBelt.APQ, CorporalPun_Wave5$HitsWithBelt.APQ, paired = TRUE)$p.value

pval = rbind(Spank.all.mod,Spank.young.mod,Spank.old.mod, Slap.all.mod, Slap.young.mod, Slap.old.mod, 
             Hit.all.mod, Hit.young.mod,Hit.old.mod)
round(pval,3)

################################################################################################################
#Run spearman correlations between corporal punishment and social activation
#Run kruskal wallis tests between corporal punishment and program attendance
################################################################################################################

Spank.progind.w4=cor.test(~`Spank hand`+`Program indirect engagement`, data = FullSample[FullSample$Wave ==4,], method = "spearman")$estimate
Spank.com.w4=cor.test(~`Spank hand`+`Community engagement`, data = FullSample[FullSample$Wave ==4,], method = "spearman")$estimate
Spank.progind.w5=cor.test(~`Spank hand`+`Program indirect engagement`, data = FullSample[FullSample$Wave ==5,], method = "spearman")$estimate
Spank.com.w5=cor.test(~`Spank hand`+`Community engagement`, data = FullSample[FullSample$Wave ==5,], method = "spearman")$estimate

Slap.progind.w4=cor.test(~`Slap child`+`Program indirect engagement`, data = FullSample[FullSample$Wave ==4,], method = "spearman")$estimate
Slap.com.w4=cor.test(~`Slap child`+`Community engagement`, data = FullSample[FullSample$Wave ==4,], method = "spearman")$estimate
Slap.progind.w5=cor.test(~`Slap child`+`Program indirect engagement`, data = FullSample[FullSample$Wave ==5,], method = "spearman")$estimate
Slap.com.w5=cor.test(~`Slap child`+`Community engagement`, data = FullSample[FullSample$Wave ==5,], method = "spearman")$estimate

Hit.progind.w4=cor.test(~`Hit child`+`Program indirect engagement`, data = FullSample[FullSample$Wave ==4,], method = "spearman")$estimate
Hit.com.w4=cor.test(~`Hit child`+`Community engagement`, data = FullSample[FullSample$Wave ==4,], method = "spearman")$estimate
Hit.progind.w5=cor.test(~`Hit child`+`Program indirect engagement`, data = FullSample[FullSample$Wave ==5,], method = "spearman")$estimate
Hit.com.w5=cor.test(~`Hit child`+`Community engagement`, data = FullSample[FullSample$Wave ==5,], method = "spearman")$estimate

pval = rbind(Spank.progind.w4,Spank.com.w4, Spank.progind.w5, Spank.com.w5, Slap.progind.w4, Slap.com.w4,Slap.progind.w5, Slap.com.w5, 
             Hit.progind.w4, Hit.com.w4, Hit.progind.w5, Hit.com.w5)
round(pval,3)

################################################################################################################
#Run kruskal wallis tests between corporal punishment and program attendance
################################################################################################################

Spank.attend = kruskal.test(`Spank hand`~ factor(`Program/s attended`), data= ParentProg_corpPun)$p.value
Slap.attend = kruskal.test(`Slap child`~ factor(`Program/s attended`), data= ParentProg_corpPun)$p.value
Hit.attend = kruskal.test(`Hit child`~ factor(`Program/s attended`), data= ParentProg_corpPun)$p.value

pval = rbind(Spank.attend, Slap.attend, Hit.attend)
round(pval,3)
